import * as assert from 'assert';
import { parseItems } from './item';

describe('item',  function() {
  it('parseItems', function() {
    // first branch
    assert.deepStrictEqual(parseItems({}), undefined);
    assert.deepStrictEqual(parseItems("hello"), undefined);

    // loop: 0-1-many 0 iterations (only one input)
    assert.deepStrictEqual(parseItems([]), []);

    // loop: 0-1-many 1 iteration, first branch
    assert.deepStrictEqual(parseItems(["hello"]), undefined);
    assert.deepStrictEqual(parseItems([[]]), undefined);

    // loop: 0-1-many 1 iteration, second branch
    assert.deepStrictEqual(parseItems([{}]), undefined);
    assert.deepStrictEqual(parseItems([{name: {}}]), undefined);

    // loop: 0-1-many 1 iteration, third branch
    assert.deepStrictEqual(parseItems([{name: "hello"}]), undefined);
    assert.deepStrictEqual(parseItems([{name: "hello", completed: {}}]), undefined);

    const items1: unknown[] = [{name: "hello", completed: true}];
    const items2: unknown[] = [{name: "james", completed: false}];

    // loop: 0-1-many 1 iteration, else branch
    assert.deepStrictEqual(parseItems(items1), items1);
    assert.deepStrictEqual(parseItems(items2), items2);

    const items3 = items1.concat([0]);
    const items4 = items2.concat([null]);

    // loop: 0-1-many many iterations, first branch
    assert.deepStrictEqual(parseItems(items3), undefined);
    assert.deepStrictEqual(parseItems(items4), undefined);

    const items5 = items1.concat([{name: undefined}]);
    const items6 = items2.concat({name: []});

    // loop: 0-1-many many iterations, second branch
    assert.deepStrictEqual(parseItems(items5), undefined);
    assert.deepStrictEqual(parseItems(items6), undefined);

    const items7 = items1.concat([{name: "world", completed: 0}]);
    const items8 = items2.concat({name: "kevin", completed: null});

    // loop: 0-1-many many iterations, third branch
    assert.deepStrictEqual(parseItems(items7), undefined);
    assert.deepStrictEqual(parseItems(items8), undefined);

    const items9 = items1.concat([{name: "world", completed: false}]);
    const items10 = items2.concat([{name: "kevin", completed: true}]);

    // loop: 0-1-many many iterations, else branch
    assert.deepStrictEqual(parseItems(items9), items9);
    assert.deepStrictEqual(parseItems(items10), items10);
  });
});
